@@ -4,7 +4,7 @@
  * This file is part of msmtp, an SMTP client, and of mpop, a POP3 client.
  *
  * Copyright (C) 2004, 2005, 2006, 2007, 2009, 2011, 2014, 2018, 2019, 2020,
- * 2021, 2022, 2023
+ * 2021, 2022, 2023, 2024, 2025
  * Martin Lambers <marlam@marlam.de>
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,7 @@
 # include <lmcons.h>
 # include <sys/locking.h>
 # include <limits.h>
+# include <winnls.h>
 #else
 # include <pwd.h>
 #endif
@@ -50,9 +51,15 @@
 #include <unistd.h>
 #ifdef ENABLE_NLS
 # include <locale.h>
+#endif
+#ifdef HAVE_LANGINFO_H
 # include <langinfo.h>
 #endif
 
+#ifdef __MINGW32__
+# include <libgen.h>
+#endif
+
 #include "xalloc.h"
 #include "base64.h"
 #include "tools.h"
@@ -310,6 +317,31 @@ const char *get_prgname(const char *argv0)
 }
 
 
+#ifdef __MINGW32__
+/*
+ * get_parentdir()
+ *
+ * Get the parent installation directory.
+ * The returned string is allocated.
+ */
+
+char *get_parentdir(void)
+{
+    char path[MAX_PATH];
+    GetModuleFileNameA(NULL, path, MAX_PATH - 1);
+
+    char *path1 = strdup(path);
+    char *progdir = dirname(path1);
+
+    char *path2 = strdup(progdir);
+    char *parentdir = dirname(path2);
+
+    free(path1);
+    return parentdir;
+}
+#endif
+
+
 /*
  * get_sysconfdir()
  *
@@ -318,7 +350,7 @@ const char *get_prgname(const char *argv0)
 
 char *get_sysconfdir(void)
 {
-#ifdef W32_NATIVE
+#if defined(_MSC_VER)
 
     BYTE sysconfdir[MAX_PATH + 1];
     HKEY hkey;
@@ -345,6 +377,13 @@ char *get_sysconfdir(void)
     RegCloseKey(hkey);
     return xstrdup((char *)sysconfdir);
 
+#elif defined(__MINGW32__)
+
+    char *parentdir = get_parentdir();
+    char *sysconfdir = get_filename(parentdir, "etc");
+    free(parentdir);
+    return sysconfdir;
+
 #else /* UNIX */
 
 #ifdef SYSCONFDIR
@@ -357,6 +396,35 @@ char *get_sysconfdir(void)
 }
 
 
+#ifdef ENABLE_NLS
+/*
+ * get_localedir()
+ *
+ * see tools.h
+ */
+
+const char *get_localedir(void)
+{
+#ifdef __MINGW32__
+    static char buf[MAX_PATH];
+    static int initialized = 0;
+    if (!initialized)
+    {
+        char *parentdir = get_parentdir();
+        char *localedir = get_filename(parentdir, "share\\locale");
+        strncpy(buf, localedir, MAX_PATH);
+        free(parentdir);
+        free(localedir);
+        initialized = 1;
+    }
+    return buf;
+#else
+    return LOCALEDIR;
+#endif
+}
+#endif
+
+
 /*
  * get_username()
  *
@@ -917,6 +985,15 @@ int check_hostname_matches_domain(const char *hostname, const char *domain)
  * see tools.h
  */
 
+#ifdef W32_NATIVE
+char *w32_langinfo_codeset()
+{
+    static char codeset[] = "CP4294967296";
+    sprintf(codeset, "CP%u", GetACP());
+    return codeset;
+}
+#endif
+
 char *encode_for_header(const char *s)
 {
     int needsEncoding = 0;
@@ -934,10 +1011,14 @@ char *encode_for_header(const char *s)
         size_t s_len = strlen(s);
         size_t b64_s_len = BASE64_LENGTH(s_len);
         char* encoding =
-#ifdef ENABLE_NLS
+#ifdef HAVE_LANGINFO_H
                 nl_langinfo(CODESET);
 #else
+# ifdef W32_NATIVE
+                w32_langinfo_codeset();
+# else
                 "UTF-8";
+# endif
 #endif
         size_t e_len = strlen(encoding);
         size_t enc_len = 2 + e_len + 3 + b64_s_len + 3;
